import { Construct } from '@aws-cdk/core';
import { ComputeType } from '@aws-cdk/aws-codebuild';
import { Rule, Schedule, OnEventOptions } from '@aws-cdk/aws-events';
import { Bucket } from '@aws-cdk/aws-s3';
export interface CentralVulnerabilityDatabaseProps {
    /**
     * Schedule for dependency check.
     */
    readonly schedule: Schedule;
    /**
     * The type of compute to use for check the repositories.
     * See the {@link ComputeType} enum for the possible values.
     *
     * @default taken from {@link #buildImage#defaultComputeType}
     */
    readonly computeType?: ComputeType;
    /**
     * Version of the dependency check
     *
     * @default 5.3.0
     */
    readonly version?: string;
    readonly centralVulnerabilityBucket: Bucket;
}
export declare class CentralVulnerabilityDatabase extends Construct {
    private readonly updateProject;
    constructor(scope: Construct, id: string, props: CentralVulnerabilityDatabaseProps);
    /**
     * Defines an event rule which triggers when an update fails.
     */
    onUpdateFailed(id: string, options?: OnEventOptions): Rule;
    /**
     * Defines an event rule which triggers when an update starts.
     */
    onUpdateStarted(id: string, options?: OnEventOptions): Rule;
    /**
     * Defines an event rule which triggers when an update complets successfully.
     */
    onUpdateSucceeded(id: string, options?: OnEventOptions): Rule;
}
